[PATCH 01/18] Xext: fix spelling mistakes

Eric Engestrom eric at engestrom.ch
Sat Apr 2 18:53:14 UTC 2016


Signed-off-by: Eric Engestrom <eric at engestrom.ch>
---
 Xext/vidmode.c | 2 +-
 Xext/xres.c    | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/Xext/vidmode.c b/Xext/vidmode.c
index 499a2a8..14d625b 100644
--- a/Xext/vidmode.c
+++ b/Xext/vidmode.c
@@ -277,7 +277,7 @@ ProcVidModeGetModeLine(ClientPtr client)
 
     /*
      * Older servers sometimes had server privates that the VidMode
-     * extention made available. So to be compatiable pretend that
+     * extension made available. So to be compatible pretend that
      * there are no server privates to pass to the client
      */
     rep.privsize = 0;
diff --git a/Xext/xres.c b/Xext/xres.c
index 83cc691..798cc5f 100644
--- a/Xext/xres.c
+++ b/Xext/xres.c
@@ -526,7 +526,7 @@ WillConstructMask(ClientPtr client, CARD32 mask,
            client id spec
 
     @param sendClient Which client wishes to receive this answer. Used for
-                      byte endianess.
+                      byte endianness.
     @param client     Which client are we considering.
     @param mask       The client id spec mask indicating which information
                       we want about this client.
@@ -693,7 +693,7 @@ ProcXResQueryClientIds (ClientPtr client)
     return rc;
 }
 
 /** @brief Swaps xXResResourceIdSpec endianess */
 static void
 SwapXResResourceIdSpec(xXResResourceIdSpec *spec)
 {
@@ -701,7 +701,7 @@ SwapXResResourceIdSpec(xXResResourceIdSpec *spec)
     swapl(&spec->type);
 }
 
 /** @brief Swaps xXResResourceSizeSpec endianess */
 static void
 SwapXResResourceSizeSpec(xXResResourceSizeSpec *size)
 {
@@ -711,7 +711,7 @@ SwapXResResourceSizeSpec(xXResResourceSizeSpec *size)
     swapl(&size->useCount);
 }
 
 /** @brief Swaps xXResResourceSizeValue endianess */
 static void
 SwapXResResourceSizeValue(xXResResourceSizeValue *rep)
 {
@@ -693,7 +693,7 @@ ProcXResQueryClientIds (ClientPtr client)
 }
 
-/** @brief Swaps xXResResourceIdSpec endianess */
+/** @brief Swaps xXResResourceIdSpec endianness */
 static void
 SwapXResResourceIdSpec(xXResResourceIdSpec *spec)
@@ -701,7 +701,7 @@ SwapXResResourceIdSpec(xXResResourceIdSpec *spec)
 }
 
-/** @brief Swaps xXResResourceSizeSpec endianess */
+/** @brief Swaps xXResResourceSizeSpec endianness */
 static void
 SwapXResResourceSizeSpec(xXResResourceSizeSpec *size)
@@ -711,7 +711,7 @@ SwapXResResourceSizeSpec(xXResResourceSizeSpec *size)
 }
 
-/** @brief Swaps xXResResourceSizeValue endianess */
+/** @brief Swaps xXResResourceSizeValue endianness */
 static void
 SwapXResResourceSizeValue(xXResResourceSizeValue *rep)
-- 
2.8.0



More information about the xorg-devel mailing list